@@ -73,8 +73,10 @@ def has_selection(treeview):
 def get_selected_value(treeview):
     selection = treeview.get_selection()
     (model, iter) = selection.get_selected()
-    value = model.get_value(iter, 0)
-    return value
+    if iter:
+        value = model.get_value(iter, 0)
+        return value
+    return None
 
 def queue_resize(treeview):
     columns = treeview.get_columns()
@@ -111,5 +113,6 @@ class ErrorDialog(gtk.MessageDialog):
     def __init__(self, primary_msg, secondary_msg):
         gtk.MessageDialog.__init__(self, parent=None, flags=gtk.DIALOG_MODAL|gtk. DIALOG_DESTROY_WITH_PARENT, type=gtk.MESSAGE_ERROR, buttons=gtk.BUTTONS_OK, message_format=primary_msg)
         self.format_secondary_text(secondary_msg)
+        self.set_title(_("Error"))
 
 # vim: set sw=4 et sts=4 tw=79 fo+=l:
