@@ -188,23 +188,6 @@ class PreferencesDialog:
 
         self.__get_widgets()
 
-        self.location_combobox.set_row_separator_func(self.__location_row_separator_func)
-        self.location_combobox.show()
-        self.location_hbox.pack_start(self.location_combobox, expand=False)
-        for location in self.config.configured_grabbers:
-            if GRABBERS.has_key(location) and Utils.is_in_path(GRABBERS[location]):
-                self.location_combobox.prepend_text(location)
-        self.location_combobox.append_text("separator")
-        self.location_combobox.append_text(_("Add new location..."))
-
-        if self.config.grabber_command != "" and \
-           len(self.config.configured_grabbers) > 0:
-
-            grabber = self.config.grabber_command.split()[0]
-            for location in self.config.configured_grabbers:
-                if GRABBERS.has_key(location) and GRABBERS[location] == grabber:
-                    GUI.set_active_from_string(self.location_combobox, location)
-
         self.show_window_hotkey_entry.set_sensitive(False)
         self.show_search_program_hotkey_entry.set_sensitive(False)
         self.show_main_window_label.set_mnemonic_widget(self.show_window_hotkey_entry.get_widget())
@@ -227,6 +210,8 @@ class PreferencesDialog:
 
         self.__add_config_notifications()
 
+        self.grabber_command_entry.set_text(self.config.grabber_command)
+        self.output_file_entry.set_text(self.config.xmltv_file)
         self.enable_hotkeys_checkbutton.set_active(self.config.enable_hotkeys)
         self.show_window_hotkey_entry.set_accelerator_name(self.config.show_window_hotkey)
         self.show_search_program_hotkey_entry.set_accelerator_name(self.config.show_search_program_hotkey)
@@ -244,8 +229,9 @@ class PreferencesDialog:
         self.notebook = xml.get_widget("notebook")
 
         # General tab
-        self.location_hbox = xml.get_widget("location_hbox")
-        self.location_combobox = gtk.combo_box_new_text()
+        self.grabber_command_entry = xml.get_widget("grabber_command_entry")
+        self.output_file_entry = xml.get_widget("output_file_entry")
+        self.browse_button = xml.get_widget("browse_button")
         self.hotkeys_table = xml.get_widget("hotkeys_table")
         self.show_main_window_label = xml.get_widget("show_main_window_label")
         self.enable_hotkeys_checkbutton = xml.get_widget("enable_hotkeys_checkbutton")
@@ -268,12 +254,6 @@ class PreferencesDialog:
         self.update_reminder_button = xml.get_widget("update_reminder_button")
         self.remove_reminder_button = xml.get_widget("remove_reminder_button")
 
-    def __location_row_separator_func(self, model, iter):
-        location = model.get_value(iter, 0)
-        if location == "separator":
-            return True
-        return False
-
     def __make_channels_treeview(self):
         self.channels_model = gtk.ListStore(object)
         self.channels_model.set_sort_func(0, self.__channels_model_sort_func)
@@ -398,8 +378,11 @@ class PreferencesDialog:
         self.dialog.connect("response", self.__dialog_response)
 
         # General tab
-        self.location_combobox.connect("changed",
-                                       self.__location_combobox_changed)
+        self.grabber_command_entry.connect("changed", self.__grabber_command_entry_changed)
+        self.grabber_command_entry.connect("activate", self.__grabber_command_entry_activated)
+        self.output_file_entry.connect("changed", self.__output_file_entry_changed)
+        self.output_file_entry.connect("activate", self.__output_file_entry_activated)
+        self.browse_button.connect("clicked", self.__browse_button_clicked)
         self.enable_hotkeys_checkbutton.connect("toggled", self.__enable_hotkeys_checkbutton_toggled)
         self.show_window_hotkey_entry.connect("accel-edited", self.__show_window_hotkey_entry_edited)
         self.show_search_program_hotkey_entry.connect("accel-edited", self.__show_search_program_hotkey_entry_edited)
@@ -440,19 +423,31 @@ class PreferencesDialog:
     def __dialog_delete(self, dialog, event):
         return True
 
-    def __location_combobox_changed(self, combobox):
-        location_combobox_active = combobox.get_active()
-        if location_combobox_active >= 0:
-            location_combobox_model = combobox.get_model()
-            selected_location = location_combobox_model[location_combobox_active][0]
-            if selected_location in self.config.configured_grabbers:
-                grabber = GRABBERS[selected_location]
-                output = os.path.expanduser("~/.xmltv/%s.xmltv" % grabber)
-                self.config.grabber_command = "%s %s %s" % (grabber, \
-                                                            "--output", output)
-            else:
-                assistant = XMLTVAssistant(self.config, self.xmltvfile)
-                assistant.show()
+    def __grabber_command_entry_changed(self, entry):
+        self.config.grabber_command = entry.get_text()
+
+    def __grabber_command_entry_activated(self, entry):
+        self.xmltvfile.download()
+
+    def __output_file_entry_changed(self, entry):
+        self.config.xmltv_file = entry.get_text()
+
+    def __output_file_entry_activated(self, entry):
+        self.xmltvfile.load()
+
+    def __browse_button_clicked(self, button):
+        xml_filter = gtk.FileFilter()
+        xml_filter.set_name(_("XML files"))
+        xml_filter.add_pattern("text/xml")
+        filters = [xml_filter]
+        fd = GUI.FileChooserDialog(_("Select XMLTV file..."), filters)
+        response = fd.run()
+        if response == gtk.RESPONSE_OK:
+            self.config.xmltv_file = fd.get_filename()
+            self.xmltvfile.load()
+            fd.hide()
+        elif response == gtk.RESPONSE_CANCEL:
+            fd.hide()
 
     def __enable_hotkeys_checkbutton_toggled(self, checkbutton):
         self.config.enable_hotkeys = checkbutton.get_active()
@@ -480,8 +475,9 @@ class PreferencesDialog:
 
     def __edit_channel_imi_activate(self, menuitem):
         channel = GUI.get_selected_value(self.channels_treeview)
-        cd = ChannelDialog(channel, self)
-        cd.show()
+        if channel:
+            cd = ChannelDialog(channel, self)
+            cd.show()
 
     def __reminders_treeview_selection_changed(self, selection):
         (reminders_model, reminders_iter) = selection.get_selected()
@@ -547,17 +543,20 @@ class PreferencesDialog:
     def __update_reminder_button_clicked(self, button):
         selection = self.reminders_treeview.get_selection()
         (reminders_model, reminders_iter) = selection.get_selected()
-        current_reminder = reminders_model.get_value(reminders_iter, 0)
-        new_reminder = self.__get_reminder()
-        if not current_reminder is new_reminder:
-            self.reminders.update(current_reminder, new_reminder)
-            reminders_model.set_value(reminders_iter, 0, new_reminder)
-            GUI.queue_resize(self.reminders_treeview)
-            self.reminders.save()
-            self.add_reminder_button.set_sensitive(False)
-            self.update_reminder_button.set_sensitive(False)
-            self.sd.search_treeview.get_selection().emit("changed")
-            self.pw.update()
+        if not reminders_iter:
+            self.add_reminder_button.clicked()
+        else:
+            current_reminder = reminders_model.get_value(reminders_iter, 0)
+            new_reminder = self.__get_reminder()
+            if not current_reminder is new_reminder:
+                self.reminders.update(current_reminder, new_reminder)
+                reminders_model.set_value(reminders_iter, 0, new_reminder)
+                GUI.queue_resize(self.reminders_treeview)
+                self.reminders.save()
+                self.add_reminder_button.set_sensitive(False)
+                self.update_reminder_button.set_sensitive(False)
+                self.sd.search_treeview.get_selection().emit("changed")
+                self.pw.update()
 
     def __remove_reminder_button_clicked(self, button):
         selection = self.reminders_treeview.get_selection()
@@ -573,8 +572,8 @@ class PreferencesDialog:
     def __add_config_notifications(self):
         self.config.add_notify(Configuration.KEY_GRABBER_COMMAND,
                                self.__grabber_command_key_changed)
-        self.config.add_notify(Configuration.KEY_CONFIGURED_GRABBERS,
-                               self.__configured_grabbers_key_changed)
+        self.config.add_notify(Configuration.KEY_XMLTV_FILE,
+                               self.__xmltv_file_key_changed)
         self.config.add_notify(Configuration.KEY_DISPLAY_CURRENT_PROGRAMS,
                                self.__display_current_programs_key_changed)
         self.config.add_notify(Configuration.KEY_DISPLAY_UPCOMING_PROGRAMS,
@@ -589,18 +588,13 @@ class PreferencesDialog:
     def __grabber_command_key_changed(self, client, cnxn_id, entry, data):
         if entry.value.type == gconf.VALUE_STRING:
             command = entry.value.to_string()
-            arguments = command.split()
-            if "--output" in arguments:
-                index = arguments.index("--output") + 1
-                self.xmltvfile.props.path = arguments[index]
+            self.grabber_command_entry.set_text(command)
 
-    def __configured_grabbers_key_changed(self, client, cnxn_id, entry, data):
-        if entry.value.type == gconf.VALUE_LIST:
-            configured_grabbers = [value.to_string() for value in entry.value.get_list()]
-            grabber = self.config.grabber_command.split()[0]
-            for location in configured_grabbers:
-                if GRABBERS.has_key(location) and GRABBERS[location] == grabber:
-                    GUI.set_active_from_string(self.location_combobox, location)
+    def __xmltv_file_key_changed(self, client, cnxn_id, entry, data):
+        if entry.value.type == gconf.VALUE_STRING:
+            xmltv_file = entry.value.to_string()
+            self.xmltvfile.props.path = xmltv_file
+            self.output_file_entry.set_text(xmltv_file)
 
     def __enable_hotkeys_key_changed(self, client, cnxn_id, entry, data):
         if not entry.value:
